@@ -1750,19 +1750,28 @@ class User(Base):
 
 class Pseudonym(Base):
     """
-    Модель "Псевдонимы"
+    Псевдоним пользователя
     """
-
     __tablename__ = 'pseudonyms'
 
+    # Идентификатор
     id = Column(Integer, primary_key=True)
+
+    # Пользователь
     user_id = Column(ForeignKey('users.id'))
     user = relationship('User')
+
+    # Позиция
     position = Column(Integer)
+
+    # SIS-идентификатор пользователя
     sis_user_id = Column(String(255))
 
+    # Провайдер аутентификации
+    authentication_provider_id = Column(ForeignKey('authentication_providers.id'))
+
     def __repr__(self):
-        return '<Pseudonym {} (id={})>'.format(self, self.id)
+        return f'<Pseudonym {self} (id={self.id})>'
 
     def __str__(self):
         return str(self.user)
