@@ -7,8 +7,11 @@ Base = declarative_base()
 
 
 def get_session(config):
-    engine = create_engine('postgresql+psycopg2://{}:{}@{}/canvas_production'.format(
-        config.user, config.password, config.host), pool_size=10, max_overflow=-1)
+    engine = create_engine(
+        f'postgresql+psycopg2://{config.user}:{config.password}@{config.host}/{config.name}',
+        pool_size=10,
+        max_overflow=-1,
+    )
     conn = engine.connect()
 
     session_factory = sessionmaker(bind=engine)
